@@ -61,9 +61,9 @@ name_unknown = "Неопределеный"
 
 def blinkString(text, blink=True, color="black", bold=False) -> Text:
     if blink:
-        res = f'<div class="blink"><strong><font color="{color}"</font>{text}</strong></div>'
+        res = f'<div class="blink"><font color="{color}"</font>{text}</div>'
     else:
-        res = f'<div><strong><font color="{color}"</font>{text}</strong></div>'
+        res = f'<div><font color="{color}"</font>{text}</div>'
 
     if bold == True:
         return f'<b>{res}</b>'
