@@ -22,13 +22,13 @@ def del_last_zero(value):
     return cel
 
 
-def DecimalToStr(value):
+def DecimalToStr(value, noneId_0=False):
     if value is None:
         return ''
 
     try:
-        # if value == 0:
-        #     return None
+        if value == 0 and noneId_0 is True:
+            return None
 
         res = del_last_zero(value=value)
         return res
