@@ -4,7 +4,7 @@ from django.db import transaction
 
 from isc_common import delAttr
 from isc_common.auth.models.user import User
-from isc_common.fields.code_field import CodeField, CodeStrictField
+from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
@@ -88,4 +88,4 @@ class Jasper_reports_users(AuditModel):
 
     class Meta:
         verbose_name = 'Доступ пользователей к отчетам'
-        unique_together=(('report','user','editor_identifier'),)
+        unique_together = (('report', 'user', 'editor_identifier'),)
